# Stats subpackage developing notes

These notes are used for keeping track of ToDos and porting information.

## get_hpd

### Porting status
- this point this function per se has nothing to do with high-density posterior points, it is more generic (fix by Luigi required)

### Matlab references
-  Everything in: [gethpd_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/misc/gethpd_vbmc.m)

## kl_div_mvn

### Matlab references
-  Everything in: [mvnkl.m](https://github.com/acerbilab/vbmc/blob/master/shared/mvnkl.m)
